@@ -1,21 +1,20 @@
 from enum import Enum
 from typing import Any, Dict, List, Literal, Mapping, Optional, Union
 
-from typing_extensions import assert_never
+from typing_extensions import Annotated, assert_never
 
-from aidial_sdk.chat_completion.enums import Status
-from aidial_sdk.deployment.from_request_mixin import FromRequestDeploymentMixin
-from aidial_sdk.exceptions import InvalidRequestError
-from aidial_sdk.pydantic_v1 import (
-    ConstrainedFloat,
-    ConstrainedInt,
-    ConstrainedList,
+from aidial_sdk._pydantic import (
+    PYDANTIC_V2,
     Field,
     PositiveInt,
     StrictBool,
     StrictInt,
     StrictStr,
 )
+from aidial_sdk._pydantic._compat import model_validator
+from aidial_sdk.chat_completion.enums import Status
+from aidial_sdk.deployment.from_request_mixin import FromRequestDeploymentMixin
+from aidial_sdk.exceptions import InvalidRequestError
 from aidial_sdk.utils.pydantic import ExtraAllowModel
 
 
@@ -27,6 +26,22 @@ class Attachment(ExtraAllowModel):
     reference_type: Optional[StrictStr] = None
     reference_url: Optional[StrictStr] = None
 
+    @model_validator(mode="before")
+    @classmethod
+    def check_data_or_url(cls, values: Any):
+        data, url = values.get("data"), values.get("url")
+
+        if data is None and url is None:
+            raise ValueError(
+                "Attachment must have either 'data' or 'url', but it's missing both"
+            )
+        if data is not None and url is not None:
+            raise ValueError(
+                "Attachment must have either 'data' or 'url', but it has both"
+            )
+
+        return values
+
 
 class Stage(ExtraAllowModel):
     name: StrictStr
@@ -142,29 +157,11 @@ class Function(ExtraAllowModel):
     parameters: Optional[Dict] = None
 
 
-class Temperature(ConstrainedFloat):
-    ge = 0
-    le = 2
-
-
-class TopP(ConstrainedFloat):
-    ge = 0
-    le = 1
-
-
-class N(ConstrainedInt):
-    ge = 1
-    le = 128
-
-
-class Stop(ConstrainedList):
-    max_items: int = 4
-    __args__ = tuple([StrictStr])
-
-
-class Penalty(ConstrainedFloat):
-    ge = -2
-    le = 2
+Temperature = Annotated[float, Field(ge=0, le=2)]
+TopP = Annotated[float, Field(ge=0, le=1)]
+N = Annotated[int, Field(ge=1, le=128)]
+Stop = Annotated[List[StrictStr], Field(max_length=4)]
+Penalty = Annotated[float, Field(ge=-2, le=2)]
 
 
 class ToolCustomFields(ExtraAllowModel):
@@ -205,15 +202,32 @@ class ResponseFormatJsonObject(ExtraAllowModel):
     type: Literal["json_object"]
 
 
+if PYDANTIC_V2:
+    import pydantic as pyd2
+
+
 class ResponseFormatJsonSchemaObject(ExtraAllowModel):
     description: Optional[StrictStr] = None
     name: StrictStr
     schema_: Dict[str, Any] = Field(..., alias="schema")
     strict: Optional[StrictBool] = False
 
-    def dict(self, *args, **kwargs):
-        kwargs["by_alias"] = True
-        return super().dict(*args, **kwargs)
+    if PYDANTIC_V2:
+
+        @pyd2.model_serializer(mode="wrap")
+        def serializer(
+            self, nxt: pyd2.SerializerFunctionWrapHandler
+        ) -> Dict[str, Any]:
+            ret = nxt(self)
+            ret["schema"] = ret["schema_"]
+            del ret["schema_"]
+            return ret
+
+    else:
+
+        def dict(self, *args, **kwargs):
+            kwargs["by_alias"] = True
+            return super().dict(*args, **kwargs)  # type: ignore
 
 
 class ResponseFormatJsonSchema(ExtraAllowModel):
